@@ -16,7 +16,7 @@ def main():
 
     # Read in Global Config File
     global_config = GlobalConfig.get_default()
-    file_manager = FileManager.get_instance()
+    file_manager = FileManager()
 
     # Read in Arguments
     argument_reader = ArgumentReader()
